<!-- insertion marker -->
## [v0.1.2](https://github.com/MarTrepodi/mhanndalorian-bot-api/releases/tag/0.0.1) - 2025-02-08

<small>[Compare with first commit](https://github.com/MarTrepodi/mhanndalorian-bot-api/compare/d8ca0c85027fde044efebcfd42923012183ec2d1...0.0.1)</small>
